@@ -5,7 +5,7 @@ import asyncio
 from collections import OrderedDict
 from collections.abc import Mapping
 from datetime import timedelta
-from typing import Any, Optional, cast
+from typing import Any, cast
 
 import jwt
 
@@ -24,7 +24,7 @@ EVENT_USER_UPDATED = "user_updated"
 EVENT_USER_REMOVED = "user_removed"
 
 _MfaModuleDict = dict[str, MultiFactorAuthModule]
-_ProviderKey = tuple[str, Optional[str]]
+_ProviderKey = tuple[str, str | None]
 _ProviderDict = dict[_ProviderKey, AuthProvider]
 
 
