@@ -1,5 +1,5 @@
 """Describe logbook events."""
-from homeassistant.components.logbook.const import (
+from homeassistant.components.logbook import (
     LOGBOOK_ENTRY_ENTITY_ID,
     LOGBOOK_ENTRY_MESSAGE,
     LOGBOOK_ENTRY_NAME,
@@ -21,7 +21,10 @@ def async_describe_events(hass, async_describe_event):
         if entity_id := data["request"].get("entity_id"):
             state = hass.states.get(entity_id)
             name = state.name if state else entity_id
-            message = f"sent command {data['request']['namespace']}/{data['request']['name']} for {name}"
+            message = (
+                "sent command"
+                f" {data['request']['namespace']}/{data['request']['name']} for {name}"
+            )
         else:
             message = (
                 f"sent command {data['request']['namespace']}/{data['request']['name']}"
