@@ -8,9 +8,8 @@ import async_timeout
 import axis
 from axis.configuration import Configuration
 from axis.errors import Unauthorized
-from axis.event_stream import OPERATION_INITIALIZED
-from axis.mqtt import mqtt_json_to_event
-from axis.streammanager import SIGNAL_PLAYING, STATE_STOPPED
+from axis.stream_manager import Signal, State
+from axis.vapix.interfaces.mqtt import mqtt_json_to_event
 
 from homeassistant.components import mqtt
 from homeassistant.components.mqtt import DOMAIN as MQTT_DOMAIN
@@ -51,7 +50,9 @@ from .errors import AuthenticationRequired, CannotConnect
 class AxisNetworkDevice:
     """Manages a Axis device."""
 
-    def __init__(self, hass, config_entry, api):
+    def __init__(
+        self, hass: HomeAssistant, config_entry: ConfigEntry, api: axis.AxisDevice
+    ) -> None:
         """Initialize the device."""
         self.hass = hass
         self.config_entry = config_entry
@@ -127,11 +128,6 @@ class AxisNetworkDevice:
         """Device specific event to signal a change in connection status."""
         return f"axis_reachable_{self.unique_id}"
 
-    @property
-    def signal_new_event(self):
-        """Device specific event to signal new device event available."""
-        return f"axis_new_event_{self.unique_id}"
-
     @property
     def signal_new_address(self):
         """Device specific event to signal a change in device address."""
@@ -147,15 +143,9 @@ class AxisNetworkDevice:
         Only signal state change if state change is true.
         """
 
-        if self.available != (status == SIGNAL_PLAYING):
+        if self.available != (status == Signal.PLAYING):
             self.available = not self.available
-            async_dispatcher_send(self.hass, self.signal_reachable, True)
-
-    @callback
-    def async_event_callback(self, action, event_id):
-        """Call to configure events when initialized on event stream."""
-        if action == OPERATION_INITIALIZED:
-            async_dispatcher_send(self.hass, self.signal_new_event, event_id)
+            async_dispatcher_send(self.hass, self.signal_reachable)
 
     @staticmethod
     async def async_new_address_callback(
@@ -167,11 +157,11 @@ class AxisNetworkDevice:
         This is a static method because a class method (bound method),
         can not be used with weak references.
         """
-        device = hass.data[AXIS_DOMAIN][entry.unique_id]
+        device: AxisNetworkDevice = hass.data[AXIS_DOMAIN][entry.entry_id]
         device.api.config.host = device.host
         async_dispatcher_send(hass, device.signal_new_address)
 
-    async def async_update_device_registry(self):
+    async def async_update_device_registry(self) -> None:
         """Update device registry."""
         device_registry = dr.async_get(self.hass)
         device_registry.async_get_or_create(
@@ -206,7 +196,7 @@ class AxisNetworkDevice:
         self.disconnect_from_stream()
 
         event = mqtt_json_to_event(message.payload)
-        self.api.event.update([event])
+        self.api.event.handler(event)
 
     # Setup and teardown methods
 
@@ -217,24 +207,24 @@ class AxisNetworkDevice:
             self.api.stream.connection_status_callback.append(
                 self.async_connection_status_callback
             )
-            self.api.enable_events(event_callback=self.async_event_callback)
+            self.api.enable_events()
             self.api.stream.start()
 
             if self.api.vapix.mqtt:
                 async_when_setup(self.hass, MQTT_DOMAIN, self.async_use_mqtt)
 
     @callback
-    def disconnect_from_stream(self):
+    def disconnect_from_stream(self) -> None:
         """Stop stream."""
-        if self.api.stream.state != STATE_STOPPED:
+        if self.api.stream.state != State.STOPPED:
             self.api.stream.connection_status_callback.clear()
             self.api.stream.stop()
 
-    async def shutdown(self, event):
+    async def shutdown(self, event) -> None:
         """Stop the event stream."""
         self.disconnect_from_stream()
 
-    async def async_reset(self):
+    async def async_reset(self) -> bool:
         """Reset this device to default state."""
         self.disconnect_from_stream()
 
