@@ -10,6 +10,7 @@ from pydeconz.models.sensor.ancillary_control import (
     AncillaryControlAction,
 )
 from pydeconz.models.sensor.presence import Presence, PresenceStatePresenceEvent
+from pydeconz.models.sensor.relative_rotary import RelativeRotary, RelativeRotaryEvent
 from pydeconz.models.sensor.switch import Switch
 
 from homeassistant.const import (
@@ -23,13 +24,14 @@ from homeassistant.core import callback
 from homeassistant.helpers import device_registry as dr
 from homeassistant.util import slugify
 
-from .const import CONF_ANGLE, CONF_GESTURE, LOGGER
+from .const import ATTR_DURATION, ATTR_ROTATION, CONF_ANGLE, CONF_GESTURE, LOGGER
 from .deconz_device import DeconzBase
 from .gateway import DeconzGateway
 
 CONF_DECONZ_EVENT = "deconz_event"
 CONF_DECONZ_ALARM_EVENT = "deconz_alarm_event"
 CONF_DECONZ_PRESENCE_EVENT = "deconz_presence_event"
+CONF_DECONZ_RELATIVE_ROTARY_EVENT = "deconz_relative_rotary_event"
 
 SUPPORTED_DECONZ_ALARM_EVENTS = {
     AncillaryControlAction.EMERGENCY,
@@ -47,6 +49,10 @@ SUPPORTED_DECONZ_PRESENCE_EVENTS = {
     PresenceStatePresenceEvent.APPROACHING,
     PresenceStatePresenceEvent.ABSENTING,
 }
+RELATIVE_ROTARY_DECONZ_TO_EVENT = {
+    RelativeRotaryEvent.NEW: "new",
+    RelativeRotaryEvent.REPEAT: "repeat",
+}
 
 
 async def async_setup_events(gateway: DeconzGateway) -> None:
@@ -55,7 +61,7 @@ async def async_setup_events(gateway: DeconzGateway) -> None:
     @callback
     def async_add_sensor(_: EventType, sensor_id: str) -> None:
         """Create DeconzEvent."""
-        new_event: DeconzAlarmEvent | DeconzEvent | DeconzPresenceEvent
+        new_event: DeconzAlarmEvent | DeconzEvent | DeconzPresenceEvent | DeconzRelativeRotaryEvent
         sensor = gateway.api.sensors[sensor_id]
 
         if isinstance(sensor, Switch):
@@ -69,6 +75,9 @@ async def async_setup_events(gateway: DeconzGateway) -> None:
                 return
             new_event = DeconzPresenceEvent(sensor, gateway)
 
+        elif isinstance(sensor, RelativeRotary):
+            new_event = DeconzRelativeRotaryEvent(sensor, gateway)
+
         gateway.hass.async_create_task(new_event.async_update_device_registry())
         gateway.events.append(new_event)
 
@@ -84,6 +93,10 @@ async def async_setup_events(gateway: DeconzGateway) -> None:
         async_add_sensor,
         gateway.api.sensors.presence,
     )
+    gateway.register_platform_add_device_callback(
+        async_add_sensor,
+        gateway.api.sensors.relative_rotary,
+    )
 
 
 @callback
@@ -104,7 +117,7 @@ class DeconzEventBase(DeconzBase):
 
     def __init__(
         self,
-        device: AncillaryControl | Presence | Switch,
+        device: AncillaryControl | Presence | RelativeRotary | Switch,
         gateway: DeconzGateway,
     ) -> None:
         """Register callback that will be used for signals."""
@@ -227,3 +240,29 @@ class DeconzPresenceEvent(DeconzEventBase):
         }
 
         self.gateway.hass.bus.async_fire(CONF_DECONZ_PRESENCE_EVENT, data)
+
+
+class DeconzRelativeRotaryEvent(DeconzEventBase):
+    """Relative rotary event."""
+
+    _device: RelativeRotary
+
+    @callback
+    def async_update_callback(self) -> None:
+        """Fire the event if reason is new action is updated."""
+        if (
+            self.gateway.ignore_state_updates
+            or "rotaryevent" not in self._device.changed_keys
+        ):
+            return
+
+        data = {
+            CONF_ID: self.event_id,
+            CONF_UNIQUE_ID: self.serial,
+            CONF_DEVICE_ID: self.device_id,
+            CONF_EVENT: RELATIVE_ROTARY_DECONZ_TO_EVENT[self._device.rotary_event],
+            ATTR_ROTATION: self._device.expected_rotation,
+            ATTR_DURATION: self._device.expected_event_duration,
+        }
+
+        self.gateway.hass.bus.async_fire(CONF_DECONZ_RELATIVE_ROTARY_EVENT, data)
