@@ -4,7 +4,6 @@ from __future__ import annotations
 from collections.abc import Mapping, Sequence
 import dataclasses
 import functools
-from typing import Any
 
 from homeassistant.components import recorder, sensor
 from homeassistant.const import (
@@ -24,6 +23,7 @@ ENERGY_USAGE_UNITS = {
     sensor.SensorDeviceClass.ENERGY: (
         UnitOfEnergy.GIGA_JOULE,
         UnitOfEnergy.KILO_WATT_HOUR,
+        UnitOfEnergy.MEGA_JOULE,
         UnitOfEnergy.MEGA_WATT_HOUR,
         UnitOfEnergy.WATT_HOUR,
     )
@@ -41,6 +41,7 @@ GAS_USAGE_UNITS = {
     sensor.SensorDeviceClass.ENERGY: (
         UnitOfEnergy.GIGA_JOULE,
         UnitOfEnergy.KILO_WATT_HOUR,
+        UnitOfEnergy.MEGA_JOULE,
         UnitOfEnergy.MEGA_WATT_HOUR,
         UnitOfEnergy.WATT_HOUR,
     ),
@@ -72,29 +73,94 @@ WATER_UNIT_ERROR = "entity_unexpected_unit_water"
 WATER_PRICE_UNIT_ERROR = "entity_unexpected_unit_water_price"
 
 
+def _get_placeholders(hass: HomeAssistant, issue_type: str) -> dict[str, str] | None:
+    currency = hass.config.currency
+    if issue_type == ENERGY_UNIT_ERROR:
+        return {
+            "energy_units": ", ".join(
+                ENERGY_USAGE_UNITS[sensor.SensorDeviceClass.ENERGY]
+            ),
+        }
+    if issue_type == ENERGY_PRICE_UNIT_ERROR:
+        return {
+            "price_units": ", ".join(
+                f"{currency}{unit}" for unit in ENERGY_PRICE_UNITS
+            ),
+        }
+    if issue_type == GAS_UNIT_ERROR:
+        return {
+            "energy_units": ", ".join(GAS_USAGE_UNITS[sensor.SensorDeviceClass.ENERGY]),
+            "gas_units": ", ".join(GAS_USAGE_UNITS[sensor.SensorDeviceClass.GAS]),
+        }
+    if issue_type == GAS_PRICE_UNIT_ERROR:
+        return {
+            "price_units": ", ".join(f"{currency}{unit}" for unit in GAS_PRICE_UNITS),
+        }
+    if issue_type == WATER_UNIT_ERROR:
+        return {
+            "water_units": ", ".join(WATER_USAGE_UNITS[sensor.SensorDeviceClass.WATER]),
+        }
+    if issue_type == WATER_PRICE_UNIT_ERROR:
+        return {
+            "price_units": ", ".join(f"{currency}{unit}" for unit in WATER_PRICE_UNITS),
+        }
+    return None
+
+
 @dataclasses.dataclass
 class ValidationIssue:
     """Error or warning message."""
 
     type: str
-    identifier: str
-    value: Any | None = None
+    affected_entities: set[tuple[str, float | str | None]] = dataclasses.field(
+        default_factory=set
+    )
+    translation_placeholders: dict[str, str] | None = None
+
+
+@dataclasses.dataclass
+class ValidationIssues:
+    """Container for validation issues."""
+
+    issues: dict[str, ValidationIssue] = dataclasses.field(default_factory=dict)
+
+    def __init__(self) -> None:
+        """Container for validiation issues."""
+        self.issues = {}
+
+    def add_issue(
+        self,
+        hass: HomeAssistant,
+        issue_type: str,
+        affected_entity: str,
+        detail: float | str | None = None,
+    ) -> None:
+        """Add an issue for an entity."""
+        if not (issue := self.issues.get(issue_type)):
+            self.issues[issue_type] = issue = ValidationIssue(issue_type)
+            issue.translation_placeholders = _get_placeholders(hass, issue_type)
+        issue.affected_entities.add((affected_entity, detail))
 
 
 @dataclasses.dataclass
 class EnergyPreferencesValidation:
     """Dictionary holding validation information."""
 
-    energy_sources: list[list[ValidationIssue]] = dataclasses.field(
-        default_factory=list
-    )
-    device_consumption: list[list[ValidationIssue]] = dataclasses.field(
-        default_factory=list
-    )
+    energy_sources: list[ValidationIssues] = dataclasses.field(default_factory=list)
+    device_consumption: list[ValidationIssues] = dataclasses.field(default_factory=list)
 
     def as_dict(self) -> dict:
         """Return dictionary version."""
-        return dataclasses.asdict(self)
+        return {
+            "energy_sources": [
+                [dataclasses.asdict(issue) for issue in issues.issues.values()]
+                for issues in self.energy_sources
+            ],
+            "device_consumption": [
+                [dataclasses.asdict(issue) for issue in issues.issues.values()]
+                for issues in self.device_consumption
+            ],
+        }
 
 
 @callback
@@ -105,11 +171,11 @@ def _async_validate_usage_stat(
     allowed_device_classes: Sequence[str],
     allowed_units: Mapping[str, Sequence[str]],
     unit_error: str,
-    result: list[ValidationIssue],
+    issues: ValidationIssues,
 ) -> None:
     """Validate a statistic."""
     if stat_id not in metadata:
-        result.append(ValidationIssue("statistics_not_defined", stat_id))
+        issues.add_issue(hass, "statistics_not_defined", stat_id)
 
     has_entity_source = valid_entity_id(stat_id)
 
@@ -119,54 +185,36 @@ def _async_validate_usage_stat(
     entity_id = stat_id
 
     if not recorder.is_entity_recorded(hass, entity_id):
-        result.append(
-            ValidationIssue(
-                "recorder_untracked",
-                entity_id,
-            )
-        )
+        issues.add_issue(hass, "recorder_untracked", entity_id)
         return
 
     if (state := hass.states.get(entity_id)) is None:
-        result.append(
-            ValidationIssue(
-                "entity_not_defined",
-                entity_id,
-            )
-        )
+        issues.add_issue(hass, "entity_not_defined", entity_id)
         return
 
     if state.state in (STATE_UNAVAILABLE, STATE_UNKNOWN):
-        result.append(ValidationIssue("entity_unavailable", entity_id, state.state))
+        issues.add_issue(hass, "entity_unavailable", entity_id, state.state)
         return
 
     try:
         current_value: float | None = float(state.state)
     except ValueError:
-        result.append(
-            ValidationIssue("entity_state_non_numeric", entity_id, state.state)
-        )
+        issues.add_issue(hass, "entity_state_non_numeric", entity_id, state.state)
         return
 
     if current_value is not None and current_value < 0:
-        result.append(
-            ValidationIssue("entity_negative_state", entity_id, current_value)
-        )
+        issues.add_issue(hass, "entity_negative_state", entity_id, current_value)
 
     device_class = state.attributes.get(ATTR_DEVICE_CLASS)
     if device_class not in allowed_device_classes:
-        result.append(
-            ValidationIssue(
-                "entity_unexpected_device_class",
-                entity_id,
-                device_class,
-            )
+        issues.add_issue(
+            hass, "entity_unexpected_device_class", entity_id, device_class
         )
     else:
         unit = state.attributes.get("unit_of_measurement")
 
         if device_class and unit not in allowed_units.get(device_class, []):
-            result.append(ValidationIssue(unit_error, entity_id, unit))
+            issues.add_issue(hass, unit_error, entity_id, unit)
 
     state_class = state.attributes.get(sensor.ATTR_STATE_CLASS)
 
@@ -176,20 +224,14 @@ def _async_validate_usage_stat(
         sensor.SensorStateClass.TOTAL_INCREASING,
     ]
     if state_class not in allowed_state_classes:
-        result.append(
-            ValidationIssue(
-                "entity_unexpected_state_class",
-                entity_id,
-                state_class,
-            )
-        )
+        issues.add_issue(hass, "entity_unexpected_state_class", entity_id, state_class)
 
     if (
         state_class == sensor.SensorStateClass.MEASUREMENT
         and sensor.ATTR_LAST_RESET not in state.attributes
     ):
-        result.append(
-            ValidationIssue("entity_state_class_measurement_no_last_reset", entity_id)
+        issues.add_issue(
+            hass, "entity_state_class_measurement_no_last_reset", entity_id
         )
 
 
@@ -197,32 +239,25 @@ def _async_validate_usage_stat(
 def _async_validate_price_entity(
     hass: HomeAssistant,
     entity_id: str,
-    result: list[ValidationIssue],
+    issues: ValidationIssues,
     allowed_units: tuple[str, ...],
     unit_error: str,
 ) -> None:
     """Validate that the price entity is correct."""
     if (state := hass.states.get(entity_id)) is None:
-        result.append(
-            ValidationIssue(
-                "entity_not_defined",
-                entity_id,
-            )
-        )
+        issues.add_issue(hass, "entity_not_defined", entity_id)
         return
 
     try:
         float(state.state)
     except ValueError:
-        result.append(
-            ValidationIssue("entity_state_non_numeric", entity_id, state.state)
-        )
+        issues.add_issue(hass, "entity_state_non_numeric", entity_id, state.state)
         return
 
     unit = state.attributes.get("unit_of_measurement")
 
     if unit is None or not unit.endswith(allowed_units):
-        result.append(ValidationIssue(unit_error, entity_id, unit))
+        issues.add_issue(hass, unit_error, entity_id, unit)
 
 
 @callback
@@ -230,11 +265,11 @@ def _async_validate_cost_stat(
     hass: HomeAssistant,
     metadata: dict[str, tuple[int, recorder.models.StatisticMetaData]],
     stat_id: str,
-    result: list[ValidationIssue],
+    issues: ValidationIssues,
 ) -> None:
     """Validate that the cost stat is correct."""
     if stat_id not in metadata:
-        result.append(ValidationIssue("statistics_not_defined", stat_id))
+        issues.add_issue(hass, "statistics_not_defined", stat_id)
 
     has_entity = valid_entity_id(stat_id)
 
@@ -242,10 +277,10 @@ def _async_validate_cost_stat(
         return
 
     if not recorder.is_entity_recorded(hass, stat_id):
-        result.append(ValidationIssue("recorder_untracked", stat_id))
+        issues.add_issue(hass, "recorder_untracked", stat_id)
 
     if (state := hass.states.get(stat_id)) is None:
-        result.append(ValidationIssue("entity_not_defined", stat_id))
+        issues.add_issue(hass, "entity_not_defined", stat_id)
         return
 
     state_class = state.attributes.get("state_class")
@@ -256,22 +291,18 @@ def _async_validate_cost_stat(
         sensor.SensorStateClass.TOTAL_INCREASING,
     ]
     if state_class not in supported_state_classes:
-        result.append(
-            ValidationIssue("entity_unexpected_state_class", stat_id, state_class)
-        )
+        issues.add_issue(hass, "entity_unexpected_state_class", stat_id, state_class)
 
     if (
         state_class == sensor.SensorStateClass.MEASUREMENT
         and sensor.ATTR_LAST_RESET not in state.attributes
     ):
-        result.append(
-            ValidationIssue("entity_state_class_measurement_no_last_reset", stat_id)
-        )
+        issues.add_issue(hass, "entity_state_class_measurement_no_last_reset", stat_id)
 
 
 @callback
 def _async_validate_auto_generated_cost_entity(
-    hass: HomeAssistant, energy_entity_id: str, result: list[ValidationIssue]
+    hass: HomeAssistant, energy_entity_id: str, issues: ValidationIssues
 ) -> None:
     """Validate that the auto generated cost entity is correct."""
     if energy_entity_id not in hass.data[DOMAIN]["cost_sensors"]:
@@ -280,7 +311,7 @@ def _async_validate_auto_generated_cost_entity(
 
     cost_entity_id = hass.data[DOMAIN]["cost_sensors"][energy_entity_id]
     if not recorder.is_entity_recorded(hass, cost_entity_id):
-        result.append(ValidationIssue("recorder_untracked", cost_entity_id))
+        issues.add_issue(hass, "recorder_untracked", cost_entity_id)
 
 
 async def async_validate(hass: HomeAssistant) -> EnergyPreferencesValidation:
@@ -297,7 +328,7 @@ async def async_validate(hass: HomeAssistant) -> EnergyPreferencesValidation:
 
     # Create a list of validation checks
     for source in manager.data["energy_sources"]:
-        source_result: list[ValidationIssue] = []
+        source_result = ValidationIssues()
         result.energy_sources.append(source_result)
 
         if source["type"] == "grid":
@@ -550,7 +581,7 @@ async def async_validate(hass: HomeAssistant) -> EnergyPreferencesValidation:
             )
 
     for device in manager.data["device_consumption"]:
-        device_result: list[ValidationIssue] = []
+        device_result = ValidationIssues()
         result.device_consumption.append(device_result)
         wanted_statistics_metadata.add(device["stat_consumption"])
         validate_calls.append(
