@@ -3,12 +3,13 @@ from __future__ import annotations
 
 from collections import Counter, deque
 from copy import copy
+from dataclasses import dataclass
 from datetime import datetime, timedelta
 from functools import partial
 import logging
 from numbers import Number
 import statistics
-from typing import Any
+from typing import Any, cast
 
 import voluptuous as vol
 
@@ -40,7 +41,7 @@ import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.event import async_track_state_change_event
 from homeassistant.helpers.reload import async_setup_reload_service
-from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
+from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType, StateType
 from homeassistant.util.decorator import Registry
 import homeassistant.util.dt as dt_util
 
@@ -211,7 +212,7 @@ class SensorFilter(SensorEntity):
         self._attr_unique_id = unique_id
         self._entity = entity_id
         self._attr_native_unit_of_measurement = None
-        self._state: str | None = None
+        self._state: StateType = None
         self._filters = filters
         self._attr_icon = None
         self._attr_device_class = None
@@ -242,7 +243,7 @@ class SensorFilter(SensorEntity):
             self.async_write_ha_state()
             return
 
-        temp_state = new_state
+        temp_state = _State(new_state.last_updated, new_state.state)
 
         try:
             for filt in self._filters:
@@ -302,14 +303,14 @@ class SensorFilter(SensorEntity):
             for filt in self._filters:
                 if (
                     filt.window_unit == WINDOW_SIZE_UNIT_NUMBER_EVENTS
-                    and largest_window_items < filt.window_size
+                    and largest_window_items < (size := cast(int, filt.window_size))
                 ):
-                    largest_window_items = filt.window_size
+                    largest_window_items = size
                 elif (
                     filt.window_unit == WINDOW_SIZE_UNIT_TIME
-                    and largest_window_time < filt.window_size
+                    and largest_window_time < (val := cast(timedelta, filt.window_size))
                 ):
-                    largest_window_time = filt.window_size
+                    largest_window_time = val
 
             # Retrieve the largest window_size of each type
             if largest_window_items > 0:
@@ -361,10 +362,10 @@ class SensorFilter(SensorEntity):
         )
 
     @property
-    def native_value(self) -> datetime | str | None:
+    def native_value(self) -> datetime | StateType:
         """Return the state of the sensor."""
         if self._state is not None and self.device_class == SensorDeviceClass.TIMESTAMP:
-            return datetime.fromisoformat(self._state)
+            return datetime.fromisoformat(str(self._state))
 
         return self._state
 
@@ -372,7 +373,9 @@ class SensorFilter(SensorEntity):
 class FilterState:
     """State abstraction for filter usage."""
 
-    def __init__(self, state):
+    state: str | float | int
+
+    def __init__(self, state: _State) -> None:
         """Initialize with HA State object."""
         self.timestamp = state.last_updated
         try:
@@ -380,31 +383,43 @@ class FilterState:
         except ValueError:
             self.state = state.state
 
-    def set_precision(self, precision):
+    def set_precision(self, precision: int) -> None:
         """Set precision of Number based states."""
         if isinstance(self.state, Number):
             value = round(float(self.state), precision)
             self.state = int(value) if precision == 0 else value
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return state as the string representation of FilterState."""
         return str(self.state)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Return timestamp and state as the representation of FilterState."""
         return f"{self.timestamp} : {self.state}"
 
 
+@dataclass
+class _State:
+    """Simplified State class.
+
+    The standard State class only accepts string in `state`,
+    and we are only interested in two properties.
+    """
+
+    last_updated: datetime
+    state: str | float | int
+
+
 class Filter:
     """Filter skeleton."""
 
     def __init__(
         self,
-        name,
-        window_size: int = 1,
-        precision: int | None = None,
-        entity: str | None = None,
-    ):
+        name: str,
+        window_size: int | timedelta,
+        precision: int,
+        entity: str,
+    ) -> None:
         """Initialize common attributes.
 
         :param window_size: size of the sliding window that holds previous values
@@ -412,12 +427,12 @@ class Filter:
         :param entity: used for debugging only
         """
         if isinstance(window_size, int):
-            self.states: deque = deque(maxlen=window_size)
+            self.states: deque[FilterState] = deque(maxlen=window_size)
             self.window_unit = WINDOW_SIZE_UNIT_NUMBER_EVENTS
         else:
             self.states = deque(maxlen=0)
             self.window_unit = WINDOW_SIZE_UNIT_TIME
-        self.precision = precision
+        self.filter_precision = precision
         self._name = name
         self._entity = entity
         self._skip_processing = False
@@ -426,32 +441,32 @@ class Filter:
         self._only_numbers = True
 
     @property
-    def window_size(self):
+    def window_size(self) -> int | timedelta:
         """Return window size."""
         return self._window_size
 
     @property
-    def name(self):
+    def name(self) -> str:
         """Return filter name."""
         return self._name
 
     @property
-    def skip_processing(self):
+    def skip_processing(self) -> bool:
         """Return whether the current filter_state should be skipped."""
         return self._skip_processing
 
-    def _filter_state(self, new_state):
+    def _filter_state(self, new_state: FilterState) -> FilterState:
         """Implement filter."""
         raise NotImplementedError()
 
-    def filter_state(self, new_state):
+    def filter_state(self, new_state: _State) -> _State:
         """Implement a common interface for filters."""
         fstate = FilterState(new_state)
         if self._only_numbers and not isinstance(fstate.state, Number):
             raise ValueError(f"State <{fstate.state}> is not a Number")
 
         filtered = self._filter_state(fstate)
-        filtered.set_precision(self.precision)
+        filtered.set_precision(self.filter_precision)
         if self._store_raw:
             self.states.append(copy(FilterState(new_state)))
         else:
@@ -470,25 +485,28 @@ class RangeFilter(Filter, SensorEntity):
 
     def __init__(
         self,
-        entity,
-        precision: int | None = DEFAULT_PRECISION,
+        entity: str,
+        precision: int,
         lower_bound: float | None = None,
         upper_bound: float | None = None,
-    ):
+    ) -> None:
         """Initialize Filter.
 
         :param upper_bound: band upper bound
         :param lower_bound: band lower bound
         """
-        super().__init__(FILTER_NAME_RANGE, precision=precision, entity=entity)
+        super().__init__(FILTER_NAME_RANGE, DEFAULT_WINDOW_SIZE, precision, entity)
         self._lower_bound = lower_bound
         self._upper_bound = upper_bound
         self._stats_internal: Counter = Counter()
 
-    def _filter_state(self, new_state):
+    def _filter_state(self, new_state: FilterState) -> FilterState:
         """Implement the range filter."""
 
-        if self._upper_bound is not None and new_state.state > self._upper_bound:
+        # We can cast safely here thanks to self._only_numbers = True
+        new_state_value = cast(float, new_state.state)
+
+        if self._upper_bound is not None and new_state_value > self._upper_bound:
 
             self._stats_internal["erasures_up"] += 1
 
@@ -500,7 +518,7 @@ class RangeFilter(Filter, SensorEntity):
             )
             new_state.state = self._upper_bound
 
-        elif self._lower_bound is not None and new_state.state < self._lower_bound:
+        elif self._lower_bound is not None and new_state_value < self._lower_bound:
 
             self._stats_internal["erasures_low"] += 1
 
@@ -522,7 +540,9 @@ class OutlierFilter(Filter, SensorEntity):
     Determines if new state is in a band around the median.
     """
 
-    def __init__(self, window_size, precision, entity, radius: float):
+    def __init__(
+        self, window_size: int, precision: int, entity: str, radius: float
+    ) -> None:
         """Initialize Filter.
 
         :param radius: band radius
@@ -532,13 +552,17 @@ class OutlierFilter(Filter, SensorEntity):
         self._stats_internal: Counter = Counter()
         self._store_raw = True
 
-    def _filter_state(self, new_state):
+    def _filter_state(self, new_state: FilterState) -> FilterState:
         """Implement the outlier filter."""
 
-        median = statistics.median([s.state for s in self.states]) if self.states else 0
+        # We can cast safely here thanks to self._only_numbers = True
+        previous_state_values = [cast(float, s.state) for s in self.states]
+        new_state_value = cast(float, new_state.state)
+
+        median = statistics.median(previous_state_values) if self.states else 0
         if (
             len(self.states) == self.states.maxlen
-            and abs(new_state.state - median) > self._radius
+            and abs(new_state_value - median) > self._radius
         ):
 
             self._stats_internal["erasures"] += 1
@@ -557,12 +581,14 @@ class OutlierFilter(Filter, SensorEntity):
 class LowPassFilter(Filter, SensorEntity):
     """BASIC Low Pass Filter."""
 
-    def __init__(self, window_size, precision, entity, time_constant: int):
+    def __init__(
+        self, window_size: int, precision: int, entity: str, time_constant: int
+    ) -> None:
         """Initialize Filter."""
         super().__init__(FILTER_NAME_LOWPASS, window_size, precision, entity)
         self._time_constant = time_constant
 
-    def _filter_state(self, new_state):
+    def _filter_state(self, new_state: FilterState) -> FilterState:
         """Implement the low pass filter."""
 
         if not self.states:
@@ -570,9 +596,10 @@ class LowPassFilter(Filter, SensorEntity):
 
         new_weight = 1.0 / self._time_constant
         prev_weight = 1.0 - new_weight
-        new_state.state = (
-            prev_weight * self.states[-1].state + new_weight * new_state.state
-        )
+        # We can cast safely here thanks to self._only_numbers = True
+        prev_state_value = cast(float, self.states[-1].state)
+        new_state_value = cast(float, new_state.state)
+        new_state.state = prev_weight * prev_state_value + new_weight * new_state_value
 
         return new_state
 
@@ -585,18 +612,22 @@ class TimeSMAFilter(Filter, SensorEntity):
     """
 
     def __init__(
-        self, window_size, precision, entity, type
-    ):  # pylint: disable=redefined-builtin
+        self,
+        window_size: timedelta,
+        precision: int,
+        entity: str,
+        type: str,  # pylint: disable=redefined-builtin
+    ) -> None:
         """Initialize Filter.
 
         :param type: type of algorithm used to connect discrete values
         """
         super().__init__(FILTER_NAME_TIME_SMA, window_size, precision, entity)
         self._time_window = window_size
-        self.last_leak = None
-        self.queue = deque()
+        self.last_leak: FilterState | None = None
+        self.queue = deque[FilterState]()
 
-    def _leak(self, left_boundary):
+    def _leak(self, left_boundary: datetime) -> None:
         """Remove timeouted elements."""
         while self.queue:
             if self.queue[0].timestamp + self._time_window <= left_boundary:
@@ -604,17 +635,19 @@ class TimeSMAFilter(Filter, SensorEntity):
             else:
                 return
 
-    def _filter_state(self, new_state):
+    def _filter_state(self, new_state: FilterState) -> FilterState:
         """Implement the Simple Moving Average filter."""
 
         self._leak(new_state.timestamp)
         self.queue.append(copy(new_state))
 
-        moving_sum = 0
+        moving_sum: float = 0
         start = new_state.timestamp - self._time_window
-        prev_state = self.last_leak or self.queue[0]
+        prev_state = self.last_leak if self.last_leak is not None else self.queue[0]
         for state in self.queue:
-            moving_sum += (state.timestamp - start).total_seconds() * prev_state.state
+            # We can cast safely here thanks to self._only_numbers = True
+            prev_state_value = cast(float, prev_state.state)
+            moving_sum += (state.timestamp - start).total_seconds() * prev_state_value
             start = state.timestamp
             prev_state = state
 
@@ -630,12 +663,12 @@ class ThrottleFilter(Filter, SensorEntity):
     One sample per window.
     """
 
-    def __init__(self, window_size, precision, entity):
+    def __init__(self, window_size: int, precision: int, entity: str) -> None:
         """Initialize Filter."""
         super().__init__(FILTER_NAME_THROTTLE, window_size, precision, entity)
         self._only_numbers = False
 
-    def _filter_state(self, new_state):
+    def _filter_state(self, new_state: FilterState) -> FilterState:
         """Implement the throttle filter."""
         if not self.states or len(self.states) == self.states.maxlen:
             self.states.clear()
@@ -653,14 +686,14 @@ class TimeThrottleFilter(Filter, SensorEntity):
     One sample per time period.
     """
 
-    def __init__(self, window_size, precision, entity):
+    def __init__(self, window_size: timedelta, precision: int, entity: str) -> None:
         """Initialize Filter."""
         super().__init__(FILTER_NAME_TIME_THROTTLE, window_size, precision, entity)
         self._time_window = window_size
-        self._last_emitted_at = None
+        self._last_emitted_at: datetime | None = None
         self._only_numbers = False
 
-    def _filter_state(self, new_state):
+    def _filter_state(self, new_state: FilterState) -> FilterState:
         """Implement the filter."""
         window_start = new_state.timestamp - self._time_window
         if not self._last_emitted_at or self._last_emitted_at <= window_start:
