@@ -4,7 +4,14 @@ from __future__ import annotations
 import logging
 from typing import Any
 
-from herepy import HEREError, InvalidCredentialsError, RouteMode, RoutingApi
+from here_routing import (
+    HERERoutingApi,
+    HERERoutingError,
+    HERERoutingUnauthorizedError,
+    Place,
+    TransportMode,
+)
+from here_transit import HERETransitError
 import voluptuous as vol
 
 from homeassistant import config_entries
@@ -14,9 +21,8 @@ from homeassistant.const import (
     CONF_LONGITUDE,
     CONF_MODE,
     CONF_NAME,
-    CONF_UNIT_SYSTEM,
 )
-from homeassistant.core import HomeAssistant, callback
+from homeassistant.core import callback
 from homeassistant.data_entry_flow import FlowResult
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.selector import (
@@ -24,7 +30,6 @@ from homeassistant.helpers.selector import (
     LocationSelector,
     TimeSelector,
 )
-from homeassistant.util.unit_system import US_CUSTOMARY_SYSTEM
 
 from .const import (
     CONF_ARRIVAL_TIME,
@@ -38,44 +43,41 @@ from .const import (
     CONF_ORIGIN_LATITUDE,
     CONF_ORIGIN_LONGITUDE,
     CONF_ROUTE_MODE,
-    CONF_TRAFFIC_MODE,
     DEFAULT_NAME,
     DOMAIN,
-    IMPERIAL_UNITS,
-    METRIC_UNITS,
     ROUTE_MODE_FASTEST,
     ROUTE_MODES,
-    TRAFFIC_MODE_ENABLED,
-    TRAFFIC_MODES,
     TRAVEL_MODE_CAR,
-    TRAVEL_MODE_PUBLIC_TIME_TABLE,
+    TRAVEL_MODE_PUBLIC,
     TRAVEL_MODES,
-    UNITS,
 )
 
 _LOGGER = logging.getLogger(__name__)
 
+DEFAULT_OPTIONS = {
+    CONF_ROUTE_MODE: ROUTE_MODE_FASTEST,
+    CONF_ARRIVAL_TIME: None,
+    CONF_DEPARTURE_TIME: None,
+}
 
-def validate_api_key(api_key: str) -> None:
+
+async def async_validate_api_key(api_key: str) -> None:
     """Validate the user input allows us to connect."""
-    known_working_origin = [38.9, -77.04833]
-    known_working_destination = [39.0, -77.1]
-    RoutingApi(api_key).public_transport_timetable(
-        known_working_origin,
-        known_working_destination,
-        True,
-        [
-            RouteMode[ROUTE_MODE_FASTEST],
-            RouteMode[TRAVEL_MODE_CAR],
-            RouteMode[TRAFFIC_MODE_ENABLED],
-        ],
-        arrival=None,
-        departure="now",
+    known_working_origin = Place(latitude=38.9, longitude=-77.04833)
+    known_working_destination = Place(latitude=39.0, longitude=-77.1)
+
+    await HERERoutingApi(api_key).route(
+        origin=known_working_origin,
+        destination=known_working_destination,
+        transport_mode=TransportMode.CAR,
     )
 
 
 def get_user_step_schema(data: dict[str, Any]) -> vol.Schema:
     """Get a populated schema or default."""
+    travel_mode = data.get(CONF_MODE, TRAVEL_MODE_CAR)
+    if travel_mode == "publicTransportTimeTable":
+        travel_mode = TRAVEL_MODE_PUBLIC
     return vol.Schema(
         {
             vol.Optional(
@@ -89,20 +91,6 @@ def get_user_step_schema(data: dict[str, Any]) -> vol.Schema:
     )
 
 
-def default_options(hass: HomeAssistant) -> dict[str, str | None]:
-    """Get the default options."""
-    default = {
-        CONF_TRAFFIC_MODE: TRAFFIC_MODE_ENABLED,
-        CONF_ROUTE_MODE: ROUTE_MODE_FASTEST,
-        CONF_ARRIVAL_TIME: None,
-        CONF_DEPARTURE_TIME: None,
-        CONF_UNIT_SYSTEM: METRIC_UNITS,
-    }
-    if hass.config.units is US_CUSTOMARY_SYSTEM:
-        default[CONF_UNIT_SYSTEM] = IMPERIAL_UNITS
-    return default
-
-
 class HERETravelTimeConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
     """Handle a config flow for HERE Travel Time."""
 
@@ -128,12 +116,10 @@ class HERETravelTimeConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         user_input = user_input or {}
         if user_input:
             try:
-                await self.hass.async_add_executor_job(
-                    validate_api_key, user_input[CONF_API_KEY]
-                )
-            except InvalidCredentialsError:
+                await async_validate_api_key(user_input[CONF_API_KEY])
+            except HERERoutingUnauthorizedError:
                 errors["base"] = "invalid_auth"
-            except HEREError as error:
+            except (HERERoutingError, HERETransitError) as error:
                 _LOGGER.exception("Unexpected exception: %s", error)
                 errors["base"] = "unknown"
             if not errors:
@@ -200,7 +186,7 @@ class HERETravelTimeConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             return self.async_create_entry(
                 title=self._config[CONF_NAME],
                 data=self._config,
-                options=default_options(self.hass),
+                options=DEFAULT_OPTIONS,
             )
         schema = vol.Schema(
             {
@@ -229,7 +215,7 @@ class HERETravelTimeConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             return self.async_create_entry(
                 title=self._config[CONF_NAME],
                 data=self._config,
-                options=default_options(self.hass),
+                options=DEFAULT_OPTIONS,
             )
         schema = vol.Schema(
             {vol.Required(CONF_DESTINATION_ENTITY_ID): EntitySelector()}
@@ -251,37 +237,19 @@ class HERETravelTimeOptionsFlow(config_entries.OptionsFlow):
         """Manage the HERE Travel Time options."""
         if user_input is not None:
             self._config = user_input
-            if self.config_entry.data[CONF_MODE] == TRAVEL_MODE_PUBLIC_TIME_TABLE:
-                return self.async_show_menu(
-                    step_id="time_menu",
-                    menu_options=["departure_time", "arrival_time", "no_time"],
-                )
             return self.async_show_menu(
                 step_id="time_menu",
-                menu_options=["departure_time", "no_time"],
+                menu_options=["departure_time", "arrival_time", "no_time"],
             )
 
-        defaults = default_options(self.hass)
         schema = vol.Schema(
             {
-                vol.Optional(
-                    CONF_TRAFFIC_MODE,
-                    default=self.config_entry.options.get(
-                        CONF_TRAFFIC_MODE, defaults[CONF_TRAFFIC_MODE]
-                    ),
-                ): vol.In(TRAFFIC_MODES),
                 vol.Optional(
                     CONF_ROUTE_MODE,
                     default=self.config_entry.options.get(
-                        CONF_ROUTE_MODE, defaults[CONF_ROUTE_MODE]
+                        CONF_ROUTE_MODE, DEFAULT_OPTIONS[CONF_ROUTE_MODE]
                     ),
                 ): vol.In(ROUTE_MODES),
-                vol.Optional(
-                    CONF_UNIT_SYSTEM,
-                    default=self.config_entry.options.get(
-                        CONF_UNIT_SYSTEM, defaults[CONF_UNIT_SYSTEM]
-                    ),
-                ): vol.In(UNITS),
             }
         )
 
