@@ -2,7 +2,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Any, TypedDict
+from typing import Any, Final, TypedDict
 
 from pylutron_caseta.smartbridge import Smartbridge
 import voluptuous as vol
@@ -45,11 +45,30 @@ class LutronKeypad(TypedDict):
     buttons: list[int]
 
 
+LUTRON_KEYPAD_LUTRON_DEVICE_ID: Final = "lutron_device_id"
+LUTRON_KEYPAD_DEVICE_REGISTRY_DEVICE_ID: Final = "dr_device_id"
+LUTRON_KEYPAD_AREA_ID: Final = "area_id"
+LUTRON_KEYPAD_AREA_NAME: Final = "area_name"
+LUTRON_KEYPAD_NAME: Final = "name"
+LUTRON_KEYPAD_SERIAL: Final = "serial"
+LUTRON_KEYPAD_DEVICE_INFO: Final = "device_info"
+LUTRON_KEYPAD_MODEL: Final = "model"
+LUTRON_KEYPAD_TYPE: Final = "type"
+LUTRON_KEYPAD_BUTTONS: Final = "buttons"
+
+
 class LutronButton(TypedDict):
     """A lutron_caseta button."""
 
     lutron_device_id: int
     leap_button_number: int
     button_name: str
-    led_device_id: int
+    led_device_id: str | None
     parent_keypad: int
+
+
+LUTRON_BUTTON_LUTRON_DEVICE_ID: Final = "lutron_device_id"
+LUTRON_BUTTON_LEAP_BUTTON_NUMBER: Final = "leap_button_number"
+LUTRON_BUTTON_BUTTON_NAME: Final = "button_name"
+LUTRON_BUTTON_LED_DEVICE_ID: Final = "led_device_id"
+LUTRON_BUTTON_PARENT_KEYPAD: Final = "parent_keypad"
