@@ -12,12 +12,11 @@ from homeassistant.components.sensor import (
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
-    ATTR_ATTRIBUTION,
-    LENGTH_KILOMETERS,
     PERCENTAGE,
-    SPEED_MILES_PER_HOUR,
-    TEMP_CELSIUS,
     UV_INDEX,
+    UnitOfLength,
+    UnitOfSpeed,
+    UnitOfTemperature,
 )
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -52,7 +51,6 @@ SENSOR_TYPES: tuple[SensorEntityDescription, ...] = (
         key="name",
         name="Station name",
         device_class=None,
-        native_unit_of_measurement=None,
         icon="mdi:label-outline",
         entity_registry_enabled_default=False,
     ),
@@ -60,7 +58,6 @@ SENSOR_TYPES: tuple[SensorEntityDescription, ...] = (
         key="weather",
         name="Weather",
         device_class=None,
-        native_unit_of_measurement=None,
         icon="mdi:weather-sunny",  # but will adapt to current conditions
         entity_registry_enabled_default=True,
     ),
@@ -68,7 +65,7 @@ SENSOR_TYPES: tuple[SensorEntityDescription, ...] = (
         key="temperature",
         name="Temperature",
         device_class=SensorDeviceClass.TEMPERATURE,
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         icon=None,
         entity_registry_enabled_default=True,
     ),
@@ -76,45 +73,47 @@ SENSOR_TYPES: tuple[SensorEntityDescription, ...] = (
         key="feels_like_temperature",
         name="Feels like temperature",
         device_class=SensorDeviceClass.TEMPERATURE,
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         icon=None,
         entity_registry_enabled_default=False,
     ),
     SensorEntityDescription(
         key="wind_speed",
         name="Wind speed",
-        native_unit_of_measurement=SPEED_MILES_PER_HOUR,
-        device_class=SensorDeviceClass.SPEED,
-        icon="mdi:weather-windy",
+        native_unit_of_measurement=UnitOfSpeed.MILES_PER_HOUR,
+        # Hint mph because that's the preferred unit for wind speeds in UK
+        # This can be removed if we add a mixed metric/imperial unit system for UK users
+        suggested_unit_of_measurement=UnitOfSpeed.MILES_PER_HOUR,
+        device_class=SensorDeviceClass.WIND_SPEED,
         entity_registry_enabled_default=True,
     ),
     SensorEntityDescription(
         key="wind_direction",
         name="Wind direction",
-        native_unit_of_measurement=None,
         icon="mdi:compass-outline",
         entity_registry_enabled_default=False,
     ),
     SensorEntityDescription(
         key="wind_gust",
         name="Wind gust",
-        native_unit_of_measurement=SPEED_MILES_PER_HOUR,
-        device_class=SensorDeviceClass.SPEED,
-        icon="mdi:weather-windy",
+        native_unit_of_measurement=UnitOfSpeed.MILES_PER_HOUR,
+        # Hint mph because that's the preferred unit for wind speeds in UK
+        # This can be removed if we add a mixed metric/imperial unit system for UK users
+        suggested_unit_of_measurement=UnitOfSpeed.MILES_PER_HOUR,
+        device_class=SensorDeviceClass.WIND_SPEED,
         entity_registry_enabled_default=False,
     ),
     SensorEntityDescription(
         key="visibility",
         name="Visibility",
         device_class=None,
-        native_unit_of_measurement=None,
         icon="mdi:eye",
         entity_registry_enabled_default=False,
     ),
     SensorEntityDescription(
         key="visibility_distance",
         name="Visibility distance",
-        native_unit_of_measurement=LENGTH_KILOMETERS,
+        native_unit_of_measurement=UnitOfLength.KILOMETERS,
         device_class=SensorDeviceClass.DISTANCE,
         icon="mdi:eye",
         entity_registry_enabled_default=False,
@@ -180,6 +179,7 @@ class MetOfficeCurrentSensor(
 ):
     """Implementation of a Met Office current weather condition sensor."""
 
+    _attr_attribution = ATTRIBUTION
     _attr_has_entity_name = True
 
     def __init__(
@@ -258,7 +258,6 @@ class MetOfficeCurrentSensor(
     def extra_state_attributes(self) -> dict[str, Any]:
         """Return the state attributes of the device."""
         return {
-            ATTR_ATTRIBUTION: ATTRIBUTION,
             ATTR_LAST_UPDATE: self.coordinator.data.now.date,
             ATTR_SENSOR_ID: self.entity_description.key,
             ATTR_SITE_ID: self.coordinator.data.site.id,
