@@ -160,7 +160,8 @@ PLATFORM_SCHEMA_LEGACY_MODERN = (
     .extend(MQTT_VACUUM_SCHEMA.schema)
 )
 
-# Configuring MQTT Vacuums under the vacuum platform key was deprecated in HA Core 2022.6
+# Configuring MQTT Vacuums under the vacuum platform key was deprecated in
+# HA Core 2022.6
 PLATFORM_SCHEMA_LEGACY = vol.All(
     cv.PLATFORM_SCHEMA.extend(PLATFORM_SCHEMA_LEGACY_MODERN.schema),
     warn_for_legacy_schema(VACUUM_DOMAIN),
@@ -413,7 +414,8 @@ class MqttVacuum(MqttEntity, VacuumEntity):
     def battery_icon(self) -> str:
         """Return the battery icon for the vacuum cleaner.
 
-        No need to check VacuumEntityFeature.BATTERY, this won't be called if battery_level is None.
+        No need to check VacuumEntityFeature.BATTERY, this won't be called if
+        battery_level is None.
         """
         return icon_for_battery_level(
             battery_level=self.battery_level, charging=self._charging
