@@ -2,12 +2,11 @@
 from __future__ import annotations
 
 import asyncio
-from collections.abc import Callable, Coroutine, Mapping
+from collections.abc import Mapping
 from datetime import timedelta
 import logging
-from typing import Any
 
-from haphilipsjs import ConnectionFailure, PhilipsTV
+from haphilipsjs import AutenticationFailure, ConnectionFailure, PhilipsTV
 from haphilipsjs.typing import SystemType
 
 from homeassistant.config_entries import ConfigEntry
@@ -18,10 +17,9 @@ from homeassistant.const import (
     CONF_USERNAME,
     Platform,
 )
-from homeassistant.core import Context, HassJob, HomeAssistant, callback
+from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.debounce import Debouncer
-from homeassistant.helpers.trigger import TriggerActionType
-from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
+from homeassistant.helpers.update_coordinator import DataUpdateCoordinator, UpdateFailed
 
 from .const import CONF_ALLOW_NOTIFY, CONF_SYSTEM, DOMAIN
 
@@ -78,42 +76,6 @@ async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     return unload_ok
 
 
-class PluggableAction:
-    """A pluggable action handler."""
-
-    def __init__(self, update: Callable[[], None]) -> None:
-        """Initialize."""
-        self._update = update
-        self._actions: dict[
-            Any, tuple[HassJob[..., Coroutine[Any, Any, None]], dict[str, Any]]
-        ] = {}
-
-    def __bool__(self):
-        """Return if we have something attached."""
-        return bool(self._actions)
-
-    @callback
-    def async_attach(self, action: TriggerActionType, variables: dict[str, Any]):
-        """Attach a device trigger for turn on."""
-
-        @callback
-        def _remove():
-            del self._actions[_remove]
-            self._update()
-
-        job = HassJob(action)
-
-        self._actions[_remove] = (job, variables)
-        self._update()
-
-        return _remove
-
-    async def async_run(self, hass: HomeAssistant, context: Context | None = None):
-        """Run all turn on triggers."""
-        for job, variables in self._actions.values():
-            hass.async_run_hass_job(job, variables, context)
-
-
 class PhilipsTVDataUpdateCoordinator(DataUpdateCoordinator[None]):
     """Coordinator to update data."""
 
@@ -125,8 +87,6 @@ class PhilipsTVDataUpdateCoordinator(DataUpdateCoordinator[None]):
         self.options = options
         self._notify_future: asyncio.Task | None = None
 
-        self.turn_on = PluggableAction(self.async_update_listeners)
-
         super().__init__(
             hass,
             LOGGER,
@@ -169,7 +129,11 @@ class PhilipsTVDataUpdateCoordinator(DataUpdateCoordinator[None]):
 
     async def _notify_task(self):
         while self._notify_wanted:
-            res = await self.api.notifyChange(130)
+            try:
+                res = await self.api.notifyChange(130)
+            except (ConnectionFailure, AutenticationFailure):
+                res = None
+
             if res:
                 self.async_set_updated_data(None)
             elif res is None:
@@ -203,3 +167,5 @@ class PhilipsTVDataUpdateCoordinator(DataUpdateCoordinator[None]):
             self._async_notify_schedule()
         except ConnectionFailure:
             pass
+        except AutenticationFailure as exception:
+            raise UpdateFailed(str(exception)) from exception
