@@ -36,6 +36,12 @@ BINARY_SENSORS: tuple[PlugwiseBinarySensorEntityDescription, ...] = (
         icon_off="mdi:hvac-off",
         entity_category=EntityCategory.DIAGNOSTIC,
     ),
+    PlugwiseBinarySensorEntityDescription(
+        key="cooling_enabled",
+        name="Cooling enabled",
+        icon="mdi:snowflake-thermometer",
+        entity_category=EntityCategory.DIAGNOSTIC,
+    ),
     PlugwiseBinarySensorEntityDescription(
         key="dhw_state",
         name="DHW state",
