@@ -86,7 +86,10 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         _LOGGER.error("No Rachio devices found in account %s", person.username)
         return False
     _LOGGER.info(
-        "%d Rachio device(s) found; The url %s must be accessible from the internet in order to receive updates",
+        (
+            "%d Rachio device(s) found; The url %s must be accessible from the internet"
+            " in order to receive updates"
+        ),
         len(person.controllers),
         webhook_url,
     )
