@@ -5,10 +5,9 @@ import asyncio
 from collections.abc import Awaitable, Callable, Coroutine
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Any, TypeVar
+from typing import Any, Concatenate, ParamSpec, TypeVar
 
 from regenmaschine.errors import RainMachineError
-from typing_extensions import Concatenate, ParamSpec
 import voluptuous as vol
 
 from homeassistant.components.switch import SwitchEntity, SwitchEntityDescription
@@ -22,19 +21,28 @@ from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from . import RainMachineData, RainMachineEntity, async_update_programs_and_zones
 from .const import (
-    CONF_ZONE_RUN_TIME,
+    CONF_DEFAULT_ZONE_RUN_TIME,
+    CONF_DURATION,
+    CONF_USE_APP_RUN_TIMES,
     DATA_PROGRAMS,
+    DATA_PROVISION_SETTINGS,
+    DATA_RESTRICTIONS_UNIVERSAL,
     DATA_ZONES,
     DEFAULT_ZONE_RUN,
     DOMAIN,
 )
-from .model import RainMachineEntityDescription, RainMachineEntityDescriptionMixinUid
-from .util import RUN_STATE_MAP
+from .model import (
+    RainMachineEntityDescription,
+    RainMachineEntityDescriptionMixinDataKey,
+    RainMachineEntityDescriptionMixinUid,
+)
+from .util import RUN_STATE_MAP, key_exists
 
 ATTR_AREA = "area"
 ATTR_CS_ON = "cs_on"
 ATTR_CURRENT_CYCLE = "current_cycle"
 ATTR_CYCLES = "cycles"
+ATTR_ZONE_RUN_TIME = "zone_run_time_from_app"
 ATTR_DELAY = "delay"
 ATTR_DELAY_ON = "delay_on"
 ATTR_FIELD_CAPACITY = "field_capacity"
@@ -130,11 +138,45 @@ def raise_on_request_error(
 class RainMachineSwitchDescription(
     SwitchEntityDescription,
     RainMachineEntityDescription,
-    RainMachineEntityDescriptionMixinUid,
 ):
     """Describe a RainMachine switch."""
 
 
+@dataclass
+class RainMachineActivitySwitchDescription(
+    RainMachineSwitchDescription, RainMachineEntityDescriptionMixinUid
+):
+    """Describe a RainMachine activity (program/zone) switch."""
+
+
+@dataclass
+class RainMachineRestrictionSwitchDescription(
+    RainMachineSwitchDescription, RainMachineEntityDescriptionMixinDataKey
+):
+    """Describe a RainMachine restriction switch."""
+
+
+TYPE_RESTRICTIONS_FREEZE_PROTECT_ENABLED = "freeze_protect_enabled"
+TYPE_RESTRICTIONS_HOT_DAYS_EXTRA_WATERING = "hot_days_extra_watering"
+
+RESTRICTIONS_SWITCH_DESCRIPTIONS = (
+    RainMachineRestrictionSwitchDescription(
+        key=TYPE_RESTRICTIONS_FREEZE_PROTECT_ENABLED,
+        name="Freeze protection",
+        icon="mdi:snowflake-alert",
+        api_category=DATA_RESTRICTIONS_UNIVERSAL,
+        data_key="freezeProtectEnabled",
+    ),
+    RainMachineRestrictionSwitchDescription(
+        key=TYPE_RESTRICTIONS_HOT_DAYS_EXTRA_WATERING,
+        name="Extra water on hot days",
+        icon="mdi:heat-wave",
+        api_category=DATA_RESTRICTIONS_UNIVERSAL,
+        data_key="hotDaysExtraWatering",
+    ),
+)
+
+
 async def async_setup_entry(
     hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback
 ) -> None:
@@ -147,7 +189,7 @@ async def async_setup_entry(
             "start_zone",
             {
                 vol.Optional(
-                    CONF_ZONE_RUN_TIME, default=DEFAULT_ZONE_RUN
+                    CONF_DEFAULT_ZONE_RUN_TIME, default=DEFAULT_ZONE_RUN
                 ): cv.positive_int
             },
             "async_start_zone",
@@ -158,8 +200,8 @@ async def async_setup_entry(
         platform.async_register_entity_service(service_name, schema, method)
 
     data: RainMachineData = hass.data[DOMAIN][entry.entry_id]
+    entities: list[RainMachineBaseSwitch] = []
 
-    entities: list[RainMachineActivitySwitch | RainMachineEnabledSwitch] = []
     for kind, api_category, switch_class, switch_enabled_class in (
         ("program", DATA_PROGRAMS, RainMachineProgram, RainMachineProgramEnabled),
         ("zone", DATA_ZONES, RainMachineZone, RainMachineZoneEnabled),
@@ -173,10 +215,9 @@ async def async_setup_entry(
                 switch_class(
                     entry,
                     data,
-                    RainMachineSwitchDescription(
+                    RainMachineActivitySwitchDescription(
                         key=f"{kind}_{uid}",
                         name=name,
-                        icon="mdi:water",
                         api_category=api_category,
                         uid=uid,
                     ),
@@ -188,17 +229,22 @@ async def async_setup_entry(
                 switch_enabled_class(
                     entry,
                     data,
-                    RainMachineSwitchDescription(
+                    RainMachineActivitySwitchDescription(
                         key=f"{kind}_{uid}_enabled",
                         name=f"{name} enabled",
-                        entity_category=EntityCategory.CONFIG,
-                        icon="mdi:cog",
                         api_category=api_category,
                         uid=uid,
                     ),
                 )
             )
 
+    # Add switches to control restrictions:
+    for description in RESTRICTIONS_SWITCH_DESCRIPTIONS:
+        coordinator = data.coordinators[description.api_category]
+        if not key_exists(coordinator.data, description.data_key):
+            continue
+        entities.append(RainMachineRestrictionSwitch(entry, data, description))
+
     async_add_entities(entities)
 
 
@@ -246,6 +292,9 @@ class RainMachineBaseSwitch(RainMachineEntity, SwitchEntity):
 class RainMachineActivitySwitch(RainMachineBaseSwitch):
     """Define a RainMachine switch to start/stop an activity (program or zone)."""
 
+    _attr_icon = "mdi:water"
+    entity_description: RainMachineActivitySwitchDescription
+
     async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn the switch off.
 
@@ -284,6 +333,10 @@ class RainMachineActivitySwitch(RainMachineBaseSwitch):
 class RainMachineEnabledSwitch(RainMachineBaseSwitch):
     """Define a RainMachine switch to enable/disable an activity (program or zone)."""
 
+    _attr_entity_category = EntityCategory.CONFIG
+    _attr_icon = "mdi:cog"
+    entity_description: RainMachineActivitySwitchDescription
+
     @callback
     def update_from_latest_data(self) -> None:
         """Update the entity when new data is received."""
@@ -360,6 +413,36 @@ class RainMachineProgramEnabled(RainMachineEnabledSwitch):
         self._update_activities()
 
 
+class RainMachineRestrictionSwitch(RainMachineBaseSwitch):
+    """Define a RainMachine restriction setting."""
+
+    _attr_entity_category = EntityCategory.CONFIG
+    entity_description: RainMachineRestrictionSwitchDescription
+
+    @raise_on_request_error
+    async def async_turn_off(self, **kwargs: Any) -> None:
+        """Disable the restriction."""
+        await self._data.controller.restrictions.set_universal(
+            {self.entity_description.data_key: False}
+        )
+        self._attr_is_on = False
+        self.async_write_ha_state()
+
+    @raise_on_request_error
+    async def async_turn_on(self, **kwargs: Any) -> None:
+        """Enable the restriction."""
+        await self._data.controller.restrictions.set_universal(
+            {self.entity_description.data_key: True}
+        )
+        self._attr_is_on = True
+        self.async_write_ha_state()
+
+    @callback
+    def update_from_latest_data(self) -> None:
+        """Update the entity when new data is received."""
+        self._attr_is_on = self.coordinator.data[self.entity_description.data_key]
+
+
 class RainMachineZone(RainMachineActivitySwitch):
     """Define a RainMachine zone."""
 
@@ -380,9 +463,21 @@ class RainMachineZone(RainMachineActivitySwitch):
     @raise_on_request_error
     async def async_turn_on_when_active(self, **kwargs: Any) -> None:
         """Turn the switch on when its associated activity is active."""
+        # 1. Use duration parameter if provided from service call
+        duration = kwargs.get(CONF_DURATION)
+        if not duration:
+            if (
+                self._entry.options[CONF_USE_APP_RUN_TIMES]
+                and ATTR_ZONE_RUN_TIME in self._attr_extra_state_attributes
+            ):
+                # 2. Use app's zone-specific default, if enabled and available
+                duration = self._attr_extra_state_attributes[ATTR_ZONE_RUN_TIME]
+            else:
+                # 3. Fall back to global zone default duration
+                duration = self._entry.options[CONF_DEFAULT_ZONE_RUN_TIME]
         await self._data.controller.zones.start(
             self.entity_description.uid,
-            kwargs.get("duration", self._entry.options[CONF_ZONE_RUN_TIME]),
+            duration,
         )
         self._update_activities()
 
@@ -418,6 +513,13 @@ class RainMachineZone(RainMachineActivitySwitch):
                     data["waterSense"]["precipitationRate"], 2
                 )
 
+        if self._entry.options[CONF_USE_APP_RUN_TIMES]:
+            provision_data = self._data.coordinators[DATA_PROVISION_SETTINGS].data
+            if zone_durations := provision_data.get("system", {}).get("zoneDuration"):
+                attrs[ATTR_ZONE_RUN_TIME] = zone_durations[
+                    list(self.coordinator.data).index(self.entity_description.uid)
+                ]
+
         self._attr_extra_state_attributes.update(attrs)
 
 
