@@ -9,8 +9,8 @@ from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_PASSWORD, CONF_UNIQUE_ID, CONF_USERNAME
 from homeassistant.core import HomeAssistant
 
-from . import RidwellData
 from .const import DOMAIN
+from .coordinator import RidwellDataUpdateCoordinator
 
 CONF_TITLE = "title"
 
@@ -27,14 +27,12 @@ async def async_get_config_entry_diagnostics(
     hass: HomeAssistant, entry: ConfigEntry
 ) -> dict[str, Any]:
     """Return diagnostics for a config entry."""
-    data: RidwellData = hass.data[DOMAIN][entry.entry_id]
+    coordinator: RidwellDataUpdateCoordinator = hass.data[DOMAIN][entry.entry_id]
 
     return async_redact_data(
         {
             "entry": entry.as_dict(),
-            "data": [
-                dataclasses.asdict(event) for event in data.coordinator.data.values()
-            ],
+            "data": [dataclasses.asdict(event) for event in coordinator.data.values()],
         },
         TO_REDACT,
     )
