@@ -6,7 +6,6 @@ from homeassistant.components.binary_sensor import (
     BinarySensorEntity,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import ATTR_ATTRIBUTION
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import entity_registry as er
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -73,6 +72,7 @@ def sense_to_mdi(sense_icon):
 class SenseDevice(BinarySensorEntity):
     """Implementation of a Sense energy device binary sensor."""
 
+    _attr_attribution = ATTRIBUTION
     _attr_should_poll = False
 
     def __init__(self, sense_devices_data, device, sense_monitor_id):
@@ -111,11 +111,6 @@ class SenseDevice(BinarySensorEntity):
         """Return the old not so unique id of the binary sensor."""
         return self._id
 
-    @property
-    def extra_state_attributes(self):
-        """Return the state attributes."""
-        return {ATTR_ATTRIBUTION: ATTRIBUTION}
-
     @property
     def icon(self):
         """Return the icon of the binary sensor."""
@@ -126,7 +121,7 @@ class SenseDevice(BinarySensorEntity):
         """Return the device class of the binary sensor."""
         return BinarySensorDeviceClass.POWER
 
-    async def async_added_to_hass(self):
+    async def async_added_to_hass(self) -> None:
         """Register callbacks."""
         self.async_on_remove(
             async_dispatcher_connect(
