@@ -8,12 +8,14 @@ import datetime
 from functools import partial
 import logging
 import socket
-from typing import TYPE_CHECKING, Any, Optional, cast
+from typing import TYPE_CHECKING, Any, cast
 from urllib.parse import urlparse
 
-from soco import events_asyncio
+from requests.exceptions import Timeout
+from soco import events_asyncio, zonegroupstate
 import soco.config as soco_config
 from soco.core import SoCo
+from soco.events_base import Event as SonosEvent, SubscriptionBase
 from soco.exceptions import SoCoException
 import voluptuous as vol
 
@@ -24,8 +26,8 @@ from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_HOSTS, EVENT_HOMEASSISTANT_STOP
 from homeassistant.core import CALLBACK_TYPE, Event, HomeAssistant, callback
 from homeassistant.helpers import config_validation as cv, device_registry as dr
-from homeassistant.helpers.dispatcher import async_dispatcher_send, dispatcher_send
-from homeassistant.helpers.event import async_track_time_interval, call_later
+from homeassistant.helpers.dispatcher import async_dispatcher_send
+from homeassistant.helpers.event import async_call_later, async_track_time_interval
 from homeassistant.helpers.typing import ConfigType
 
 from .alarms import SonosAlarms
@@ -40,6 +42,7 @@ from .const import (
     SONOS_REBOOTED,
     SONOS_SPEAKER_ACTIVITY,
     SONOS_VANISHED,
+    SUBSCRIPTION_TIMEOUT,
     UPNP_ST,
 )
 from .exception import SonosUpdateError
@@ -51,7 +54,7 @@ _LOGGER = logging.getLogger(__name__)
 CONF_ADVERTISE_ADDR = "advertise_addr"
 CONF_INTERFACE_ADDR = "interface_addr"
 DISCOVERY_IGNORED_MODELS = ["Sonos Boost"]
-
+ZGS_SUBSCRIPTION_TIMEOUT = 2
 
 CONFIG_SCHEMA = vol.Schema(
     {
@@ -122,6 +125,8 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up Sonos from a config entry."""
     soco_config.EVENTS_MODULE = events_asyncio
     soco_config.REQUEST_TIMEOUT = 9.5
+    soco_config.ZGT_EVENT_FALLBACK = False
+    zonegroupstate.EVENT_CACHE_TIMEOUT = SUBSCRIPTION_TIMEOUT
 
     if DATA_SONOS not in hass.data:
         hass.data[DATA_SONOS] = SonosData()
@@ -136,7 +141,10 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
     if deprecated_address := config.get(CONF_INTERFACE_ADDR):
         _LOGGER.warning(
-            "'%s' is deprecated, enable %s in the Network integration (https://www.home-assistant.io/integrations/network/)",
+            (
+                "'%s' is deprecated, enable %s in the Network integration"
+                " (https://www.home-assistant.io/integrations/network/)"
+            ),
             CONF_INTERFACE_ADDR,
             deprecated_address,
         )
@@ -169,6 +177,7 @@ class SonosDiscoveryManager:
         self.data = data
         self.hosts = set(hosts)
         self.discovery_lock = asyncio.Lock()
+        self.creation_lock = asyncio.Lock()
         self._known_invisible: set[SoCo] = set()
         self._manual_config_required = bool(hosts)
 
@@ -181,21 +190,70 @@ class SonosDiscoveryManager:
         """Check if device at provided IP is known to be invisible."""
         return any(x for x in self._known_invisible if x.ip_address == ip_address)
 
-    def _create_visible_speakers(self, ip_address: str) -> None:
-        """Create all visible SonosSpeaker instances with the provided seed IP."""
-        try:
-            soco = SoCo(ip_address)
+    async def async_subscribe_to_zone_updates(self, ip_address: str) -> None:
+        """Test subscriptions and create SonosSpeakers based on results."""
+        soco = SoCo(ip_address)
+        # Cache now to avoid household ID lookup during first ZoneGroupState processing
+        await self.hass.async_add_executor_job(
+            getattr,
+            soco,
+            "household_id",
+        )
+        sub = await soco.zoneGroupTopology.subscribe()
+
+        @callback
+        def _async_add_visible_zones(subscription_succeeded: bool = False) -> None:
+            """Determine visible zones and create SonosSpeaker instances."""
+            zones_to_add = set()
+            subscription = None
+            if subscription_succeeded:
+                subscription = sub
+
             visible_zones = soco.visible_zones
             self._known_invisible = soco.all_zones - visible_zones
-        except (OSError, SoCoException) as ex:
-            _LOGGER.warning(
-                "Failed to request visible zones from %s: %s", ip_address, ex
-            )
-            return
+            for zone in visible_zones:
+                if zone.uid not in self.data.discovered:
+                    zones_to_add.add(zone)
 
-        for zone in visible_zones:
-            if zone.uid not in self.data.discovered:
-                self._add_speaker(zone)
+            if not zones_to_add:
+                return
+
+            self.hass.async_create_task(
+                self.async_add_speakers(zones_to_add, subscription, soco.uid)
+            )
+
+        async def async_subscription_failed(now: datetime.datetime) -> None:
+            """Fallback logic if the subscription callback never arrives."""
+            _LOGGER.warning(
+                "Subscription to %s failed, attempting to poll directly", ip_address
+            )
+            try:
+                await sub.unsubscribe()
+                await self.hass.async_add_executor_job(soco.zone_group_state.poll, soco)
+            except (OSError, SoCoException, Timeout) as ex:
+                _LOGGER.warning(
+                    "Fallback pollling to %s failed, setup cannot continue: %s",
+                    ip_address,
+                    ex,
+                )
+                return
+            _LOGGER.debug("Fallback ZoneGroupState poll to %s succeeded", ip_address)
+            _async_add_visible_zones()
+
+        cancel_failure_callback = async_call_later(
+            self.hass, ZGS_SUBSCRIPTION_TIMEOUT, async_subscription_failed
+        )
+
+        @callback
+        def _async_subscription_succeeded(event: SonosEvent) -> None:
+            """Create SonosSpeakers when subscription callbacks successfully arrive."""
+            _LOGGER.debug("Subscription to %s succeeded", ip_address)
+            cancel_failure_callback()
+            _async_add_visible_zones(subscription_succeeded=True)
+
+        sub.callback = _async_subscription_succeeded
+        # Hold lock to prevent concurrent subscription attempts
+        await asyncio.sleep(ZGS_SUBSCRIPTION_TIMEOUT * 2)
 
     async def _async_stop_event_listener(self, event: Event | None = None) -> None:
         for speaker in self.data.discovered.values():
@@ -224,14 +282,35 @@ class SonosDiscoveryManager:
             self.data.hosts_heartbeat()
             self.data.hosts_heartbeat = None
 
-    def _add_speaker(self, soco: SoCo) -> None:
+    async def async_add_speakers(
+        self,
+        socos: set[SoCo],
+        zgs_subscription: SubscriptionBase | None,
+        zgs_subscription_uid: str | None,
+    ) -> None:
+        """Create and set up new SonosSpeaker instances."""
+
+        def _add_speakers():
+            """Add all speakers in a single executor job."""
+            for soco in socos:
+                sub = None
+                if soco.uid == zgs_subscription_uid and zgs_subscription:
+                    sub = zgs_subscription
+                self._add_speaker(soco, sub)
+
+        async with self.creation_lock:
+            await self.hass.async_add_executor_job(_add_speakers)
+
+    def _add_speaker(
+        self, soco: SoCo, zone_group_state_sub: SubscriptionBase | None
+    ) -> None:
         """Create and set up a new SonosSpeaker instance."""
         try:
             speaker_info = soco.get_speaker_info(True, timeout=7)
             if soco.uid not in self.data.boot_counts:
                 self.data.boot_counts[soco.uid] = soco.boot_seqnum
             _LOGGER.debug("Adding new speaker: %s", speaker_info)
-            speaker = SonosSpeaker(self.hass, soco, speaker_info)
+            speaker = SonosSpeaker(self.hass, soco, speaker_info, zone_group_state_sub)
             self.data.discovered[soco.uid] = speaker
             for coordinator, coord_dict in (
                 (SonosAlarms, self.data.alarms),
@@ -244,18 +323,32 @@ class SonosDiscoveryManager:
                     new_coordinator.setup(soco)
                     coord_dict[soco.household_id] = new_coordinator
             speaker.setup(self.entry)
-        except (OSError, SoCoException):
-            _LOGGER.warning("Failed to add SonosSpeaker using %s", soco, exc_info=True)
+        except (OSError, SoCoException, Timeout) as ex:
+            _LOGGER.warning("Failed to add SonosSpeaker using %s: %s", soco, ex)
 
-    def _poll_manual_hosts(self, now: datetime.datetime | None = None) -> None:
+    async def async_poll_manual_hosts(
+        self, now: datetime.datetime | None = None
+    ) -> None:
         """Add and maintain Sonos devices from a manual configuration."""
+
+        def get_sync_attributes(soco: SoCo) -> set[SoCo]:
+            """Ensure I/O attributes are cached and return visible zones."""
+            _ = soco.household_id
+            _ = soco.uid
+            return soco.visible_zones
+
         for host in self.hosts:
             ip_addr = socket.gethostbyname(host)
             soco = SoCo(ip_addr)
             try:
-                visible_zones = soco.visible_zones
-            except OSError:
-                _LOGGER.warning("Could not get visible Sonos devices from %s", ip_addr)
+                visible_zones = await self.hass.async_add_executor_job(
+                    get_sync_attributes,
+                    soco,
+                )
+            except (OSError, SoCoException, Timeout) as ex:
+                _LOGGER.warning(
+                    "Could not get visible Sonos devices from %s: %s", ip_addr, ex
+                )
             else:
                 if new_hosts := {
                     x.ip_address
@@ -264,7 +357,7 @@ class SonosDiscoveryManager:
                 }:
                     _LOGGER.debug("Adding to manual hosts: %s", new_hosts)
                     self.hosts.update(new_hosts)
-                dispatcher_send(
+                async_dispatcher_send(
                     self.hass,
                     f"{SONOS_SPEAKER_ACTIVITY}-{soco.uid}",
                     "manual zone scan",
@@ -287,7 +380,9 @@ class SonosDiscoveryManager:
                 None,
             )
             if not known_speaker:
-                self._create_visible_speakers(ip_addr)
+                await self._async_handle_discovery_message(
+                    soco.uid, ip_addr, "manual zone scan"
+                )
             elif not known_speaker.available:
                 try:
                     known_speaker.ping()
@@ -296,33 +391,32 @@ class SonosDiscoveryManager:
                         "Manual poll to %s failed, keeping unavailable", ip_addr
                     )
 
-        self.data.hosts_heartbeat = call_later(
-            self.hass, DISCOVERY_INTERVAL.total_seconds(), self._poll_manual_hosts
+        self.data.hosts_heartbeat = async_call_later(
+            self.hass, DISCOVERY_INTERVAL.total_seconds(), self.async_poll_manual_hosts
         )
 
     async def _async_handle_discovery_message(
-        self, uid: str, discovered_ip: str, boot_seqnum: int | None
+        self,
+        uid: str,
+        discovered_ip: str,
+        source: str,
+        boot_seqnum: int | None = None,
     ) -> None:
         """Handle discovered player creation and activity."""
         async with self.discovery_lock:
             if not self.data.discovered:
                 # Initial discovery, attempt to add all visible zones
-                await self.hass.async_add_executor_job(
-                    self._create_visible_speakers,
-                    discovered_ip,
-                )
+                await self.async_subscribe_to_zone_updates(discovered_ip)
             elif uid not in self.data.discovered:
                 if self.is_device_invisible(discovered_ip):
                     return
-                await self.hass.async_add_executor_job(
-                    self._add_speaker, SoCo(discovered_ip)
-                )
+                await self.async_subscribe_to_zone_updates(discovered_ip)
             elif boot_seqnum and boot_seqnum > self.data.boot_counts[uid]:
                 self.data.boot_counts[uid] = boot_seqnum
                 async_dispatcher_send(self.hass, f"{SONOS_REBOOTED}-{uid}")
             else:
                 async_dispatcher_send(
-                    self.hass, f"{SONOS_SPEAKER_ACTIVITY}-{uid}", "discovery"
+                    self.hass, f"{SONOS_SPEAKER_ACTIVITY}-{uid}", source
                 )
 
     async def _async_ssdp_discovered_player(
@@ -365,7 +459,8 @@ class SonosDiscoveryManager:
         """Handle discovery via ssdp or zeroconf."""
         if self._manual_config_required:
             _LOGGER.warning(
-                "Automatic discovery is working, Sonos hosts in configuration.yaml are not needed"
+                "Automatic discovery is working, Sonos hosts in configuration.yaml are"
+                " not needed"
             )
             self._manual_config_required = False
         if model in DISCOVERY_IGNORED_MODELS:
@@ -385,7 +480,10 @@ class SonosDiscoveryManager:
             self.data.discovery_known.add(uid)
         asyncio.create_task(
             self._async_handle_discovery_message(
-                uid, discovered_ip, cast(Optional[int], boot_seqnum)
+                uid,
+                discovered_ip,
+                "discovery",
+                boot_seqnum=cast(int | None, boot_seqnum),
             )
         )
 
@@ -404,7 +502,7 @@ class SonosDiscoveryManager:
                     EVENT_HOMEASSISTANT_STOP, self._stop_manual_heartbeat
                 )
             )
-            await self.hass.async_add_executor_job(self._poll_manual_hosts)
+            await self.async_poll_manual_hosts()
 
         self.entry.async_on_unload(
             await ssdp.async_register_callback(
