@@ -191,9 +191,8 @@ def valid_state_characteristic_configuration(config: dict[str, Any]) -> dict[str
         not is_binary and characteristic not in STATS_NUMERIC_SUPPORT
     ):
         raise vol.ValueInvalid(
-            "The configured characteristic '{}' is not supported for the configured source sensor".format(
-                characteristic
-            )
+            "The configured characteristic '{}' is not supported for the configured"
+            " source sensor".format(characteristic)
         )
     return config
 
