@@ -20,6 +20,10 @@ from systembridgeconnector.models.disk import Disk
 from systembridgeconnector.models.display import Display
 from systembridgeconnector.models.get_data import GetData
 from systembridgeconnector.models.gpu import Gpu
+from systembridgeconnector.models.media_directories import MediaDirectories
+from systembridgeconnector.models.media_files import File as MediaFile, MediaFiles
+from systembridgeconnector.models.media_get_file import MediaGetFile
+from systembridgeconnector.models.media_get_files import MediaGetFiles
 from systembridgeconnector.models.memory import Memory
 from systembridgeconnector.models.register_data_listener import RegisterDataListener
 from systembridgeconnector.models.system import System
@@ -100,6 +104,36 @@ class SystemBridgeDataUpdateCoordinator(
             self.websocket_client.get_data(GetData(modules=modules))
         )
 
+    async def async_get_media_directories(self) -> MediaDirectories:
+        """Get media directories."""
+        return await self.websocket_client.get_directories()
+
+    async def async_get_media_files(
+        self,
+        base: str,
+        path: str | None = None,
+    ) -> MediaFiles:
+        """Get media files."""
+        return await self.websocket_client.get_files(
+            MediaGetFiles(
+                base=base,
+                path=path,
+            )
+        )
+
+    async def async_get_media_file(
+        self,
+        base: str,
+        path: str,
+    ) -> MediaFile:
+        """Get media file."""
+        return await self.websocket_client.get_file(
+            MediaGetFile(
+                base=base,
+                path=path,
+            )
+        )
+
     async def async_handle_module(
         self,
         module_name: str,
