@@ -1,8 +1,6 @@
 """Support for ThermoBeacon sensors."""
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from thermobeacon_ble import (
     SensorDeviceClass as ThermoBeaconSensorDeviceClass,
     SensorUpdate,
@@ -128,9 +126,7 @@ async def async_setup_entry(
 
 
 class ThermoBeaconBluetoothSensorEntity(
-    PassiveBluetoothProcessorEntity[
-        PassiveBluetoothDataProcessor[Optional[Union[float, int]]]
-    ],
+    PassiveBluetoothProcessorEntity[PassiveBluetoothDataProcessor[float | int | None]],
     SensorEntity,
 ):
     """Representation of a ThermoBeacon sensor."""
