@@ -2,18 +2,18 @@
 from __future__ import annotations
 
 from datetime import timedelta
+from functools import partial
 import logging
 from typing import Any
 
-import transmissionrpc
-from transmissionrpc.error import TransmissionError
+import transmission_rpc
+from transmission_rpc.error import TransmissionError
 import voluptuous as vol
 
 from homeassistant.config_entries import ConfigEntry, ConfigEntryState
 from homeassistant.const import (
     CONF_HOST,
     CONF_ID,
-    CONF_NAME,
     CONF_PASSWORD,
     CONF_PORT,
     CONF_SCAN_INTERVAL,
@@ -25,7 +25,6 @@ from homeassistant.exceptions import ConfigEntryAuthFailed, ConfigEntryNotReady
 from homeassistant.helpers import config_validation as cv, selector
 from homeassistant.helpers.dispatcher import dispatcher_send
 from homeassistant.helpers.event import async_track_time_interval
-from homeassistant.helpers.issue_registry import IssueSeverity, create_issue
 
 from .const import (
     ATTR_DELETE_DATA,
@@ -55,13 +54,11 @@ _LOGGER = logging.getLogger(__name__)
 SERVICE_BASE_SCHEMA = vol.Schema(
     {
         vol.Exclusive(CONF_ENTRY_ID, "identifier"): selector.ConfigEntrySelector(),
-        vol.Exclusive(CONF_NAME, "identifier"): selector.TextSelector(),
     }
 )
 
 SERVICE_ADD_TORRENT_SCHEMA = vol.All(
     SERVICE_BASE_SCHEMA.extend({vol.Required(ATTR_TORRENT): cv.string}),
-    cv.has_at_least_one_key(CONF_ENTRY_ID, CONF_NAME),
 )
 
 
@@ -71,13 +68,11 @@ SERVICE_REMOVE_TORRENT_SCHEMA = vol.All(
             vol.Required(CONF_ID): cv.positive_int,
             vol.Optional(ATTR_DELETE_DATA, default=DEFAULT_DELETE_DATA): cv.boolean,
         }
-    ),
-    cv.has_at_least_one_key(CONF_ENTRY_ID, CONF_NAME),
+    )
 )
 
 SERVICE_START_TORRENT_SCHEMA = vol.All(
     SERVICE_BASE_SCHEMA.extend({vol.Required(CONF_ID): cv.positive_int}),
-    cv.has_at_least_one_key(CONF_ENTRY_ID, CONF_NAME),
 )
 
 SERVICE_STOP_TORRENT_SCHEMA = vol.All(
@@ -85,8 +80,7 @@ SERVICE_STOP_TORRENT_SCHEMA = vol.All(
         {
             vol.Required(CONF_ID): cv.positive_int,
         }
-    ),
-    cv.has_at_least_one_key(CONF_ENTRY_ID, CONF_NAME),
+    )
 )
 
 CONFIG_SCHEMA = cv.removed(DOMAIN, raise_if_present=False)
@@ -132,7 +126,13 @@ async def get_api(hass, entry):
 
     try:
         api = await hass.async_add_executor_job(
-            transmissionrpc.Client, host, port, username, password
+            partial(
+                transmission_rpc.Client,
+                username=username,
+                password=password,
+                host=host,
+                port=port,
+            )
         )
         _LOGGER.debug("Successfully connected to %s", host)
         return api
@@ -158,27 +158,6 @@ def _get_client(hass: HomeAssistant, data: dict[str, Any]) -> TransmissionClient
     ):
         return hass.data[DOMAIN][entry_id]
 
-    # to be removed once name key is removed
-    if CONF_NAME in data:
-        create_issue(
-            hass,
-            DOMAIN,
-            "deprecated_key",
-            breaks_in_ha_version="2023.1.0",
-            is_fixable=True,
-            is_persistent=True,
-            severity=IssueSeverity.WARNING,
-            translation_key="deprecated_key",
-        )
-
-        _LOGGER.warning(
-            'The "name" key in the Transmission services is deprecated and will be removed in "2023.1.0"; '
-            'use the "entry_id" key instead to identity which entry to call'
-        )
-        for entry in hass.config_entries.async_entries(DOMAIN):
-            if entry.data[CONF_NAME] == data[CONF_NAME]:
-                return hass.data[DOMAIN][entry.entry_id]
-
     return None
 
 
@@ -189,7 +168,7 @@ class TransmissionClient:
         """Initialize the Transmission RPC API."""
         self.hass = hass
         self.config_entry = config_entry
-        self.tm_api: transmissionrpc.Client = None
+        self.tm_api: transmission_rpc.Client = None
         self._tm_data: TransmissionData = None
         self.unsub_timer = None
 
@@ -332,18 +311,18 @@ class TransmissionClient:
 class TransmissionData:
     """Get the latest data and update the states."""
 
-    def __init__(self, hass, config, api: transmissionrpc.Client):
+    def __init__(self, hass, config, api: transmission_rpc.Client):
         """Initialize the Transmission RPC API."""
         self.hass = hass
         self.config = config
-        self.data: transmissionrpc.Session = None
+        self.data: transmission_rpc.Session = None
         self.available: bool = True
-        self._all_torrents: list[transmissionrpc.Torrent] = []
-        self._api: transmissionrpc.Client = api
-        self._completed_torrents: list[transmissionrpc.Torrent] = []
-        self._session: transmissionrpc.Session = None
-        self._started_torrents: list[transmissionrpc.Torrent] = []
-        self._torrents: list[transmissionrpc.Torrent] = []
+        self._all_torrents: list[transmission_rpc.Torrent] = []
+        self._api: transmission_rpc.Client = api
+        self._completed_torrents: list[transmission_rpc.Torrent] = []
+        self._session: transmission_rpc.Session = None
+        self._started_torrents: list[transmission_rpc.Torrent] = []
+        self._torrents: list[transmission_rpc.Torrent] = []
 
     @property
     def host(self):
@@ -356,7 +335,7 @@ class TransmissionData:
         return f"{DATA_UPDATED}-{self.host}"
 
     @property
-    def torrents(self) -> list[transmissionrpc.Torrent]:
+    def torrents(self) -> list[transmission_rpc.Torrent]:
         """Get the list of torrents."""
         return self._torrents
 
