@@ -38,7 +38,6 @@ from .const import (
     DEV_PROFILE_RGB,
     DEV_PROFILE_RGBW,
     DOMAIN,
-    HIDDEN_DEV_VALUES,
     MIN_EFFECT_VERSION,
 )
 
@@ -297,10 +296,6 @@ class TwinklyLight(LightEntity):
                     },
                 )
 
-            for key, value in device_info.items():
-                if key not in HIDDEN_DEV_VALUES:
-                    self._attributes[key] = value
-
             if LightEntityFeature.EFFECT & self.supported_features:
                 await self.async_update_movies()
                 await self.async_update_current_movie()
