@@ -800,7 +800,7 @@ async def websocket_device_cluster_commands(
 async def websocket_read_zigbee_cluster_attributes(
     hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]
 ) -> None:
-    """Read zigbee attribute for cluster on zha entity."""
+    """Read zigbee attribute for cluster on ZHA entity."""
     zha_gateway: ZHAGateway = hass.data[DATA_ZHA][DATA_ZHA_GATEWAY]
     ieee: EUI64 = msg[ATTR_IEEE]
     endpoint_id: int = msg[ATTR_ENDPOINT_ID]
@@ -1318,7 +1318,7 @@ def async_load_api(hass: HomeAssistant) -> None:
     )
 
     async def issue_zigbee_cluster_command(service: ServiceCall) -> None:
-        """Issue command on zigbee cluster on zha entity."""
+        """Issue command on zigbee cluster on ZHA entity."""
         ieee: EUI64 = service.data[ATTR_IEEE]
         endpoint_id: int = service.data[ATTR_ENDPOINT_ID]
         cluster_id: int = service.data[ATTR_CLUSTER_ID]
