@@ -397,7 +397,10 @@ class ZHADevice(LogMixin):
             or not self._channels.pools
         ):
             self.debug(
-                "last_seen is %s seconds ago and ping attempts have been exhausted, marking the device unavailable",
+                (
+                    "last_seen is %s seconds ago and ping attempts have been exhausted,"
+                    " marking the device unavailable"
+                ),
                 difference,
             )
             self.update_available(False)
@@ -422,7 +425,10 @@ class ZHADevice(LogMixin):
     def update_available(self, available: bool) -> None:
         """Update device availability and signal entities."""
         self.debug(
-            "Update device availability -  device available: %s - new availability: %s - changed: %s",
+            (
+                "Update device availability -  device available: %s - new availability:"
+                " %s - changed: %s"
+            ),
             self.available,
             available,
             self.available ^ available,
@@ -432,7 +438,8 @@ class ZHADevice(LogMixin):
         if availability_changed and available:
             # reinit channels then signal entities
             self.debug(
-                "Device availability changed and device became available, reinitializing channels"
+                "Device availability changed and device became available,"
+                " reinitializing channels"
             )
             self.hass.async_create_task(self._async_became_available())
             return
@@ -562,8 +569,10 @@ class ZHADevice(LogMixin):
             else:
                 names.append(
                     {
-                        ATTR_NAME: f"unknown {endpoint.device_type} device_type "
-                        f"of 0x{(endpoint.profile_id or 0xFFFF):04x} profile id"
+                        ATTR_NAME: (
+                            f"unknown {endpoint.device_type} device_type "
+                            f"of 0x{(endpoint.profile_id or 0xFFFF):04x} profile id"
+                        )
                     }
                 )
         device_info[ATTR_ENDPOINT_NAMES] = names
@@ -696,7 +705,8 @@ class ZHADevice(LogMixin):
             )
         except KeyError as exc:
             raise ValueError(
-                f"Cluster {cluster_id} not found on endpoint {endpoint_id} while issuing command {command} with args {args}"
+                f"Cluster {cluster_id} not found on endpoint {endpoint_id} while"
+                f" issuing command {command} with args {args}"
             ) from exc
         commands: dict[int, ZCLCommandDef] = (
             cluster.server_commands
@@ -705,7 +715,10 @@ class ZHADevice(LogMixin):
         )
         if args is not None:
             self.warning(
-                "args [%s] are deprecated and should be passed with the params key. The parameter names are: %s",
+                (
+                    "args [%s] are deprecated and should be passed with the params key."
+                    " The parameter names are: %s"
+                ),
                 args,
                 [field.name for field in commands[command].schema.fields],
             )
@@ -790,7 +803,10 @@ class ZHADevice(LogMixin):
             await self._zigpy_device.endpoints[endpoint_id].remove_from_group(group_id)
         except (zigpy.exceptions.ZigbeeException, asyncio.TimeoutError) as ex:
             self.debug(
-                "Failed to remove endpoint: %s for device '%s' from group: 0x%04x ex: %s",
+                (
+                    "Failed to remove endpoint: %s for device '%s' from group: 0x%04x"
+                    " ex: %s"
+                ),
                 endpoint_id,
                 self._zigpy_device.ieee,
                 group_id,
